// API_Key
const API_KEY = 'API_KEY';

// Global stats object
let stats = {
    total: 0,
    assigned: 0,
    categories: new Set()
};

// Initialize
// Initialize
document.addEventListener('DOMContentLoaded', function() {
    // Initialize UI elements
    const analyzeBtn = document.querySelector('.analyze-btn');
    const exportBtn = document.getElementById('export-btn');
    const totalNumber = document.querySelector('.total-number');
    const assignedNumber = document.querySelector('.assigned-number');
    const categoriesNumber = document.querySelector('.categories-number');
    const commentsList = document.querySelector('.comments-list');
    const loading = document.querySelector('.loading');
    
    // Store analyzed comments for export
    let analyzedComments = [];
    // Reset stats
    resetStats();

    // Add click handler
    analyzeBtn.addEventListener('click', async () => {
        try {
            // Show loading state
            loading.style.display = 'block';
            commentsList.innerHTML = '';
            resetStats();

            // Get current tab
            const [tab] = await chrome.tabs.query({ 
                active: true, 
                currentWindow: true 
            });

            // Inject content script
            await chrome.scripting.executeScript({
                target: { tabId: tab.id },
                files: ['contentScript.js']
            });

            // Get comments from page
            const response = await chrome.tabs.sendMessage(tab.id, { 
                action: 'getComments' 
            });

            if (!response?.comments?.length) {
                throw new Error('No comments found on this page');
            }

            // Process each comment
            for (const comment of response.comments) {
                if (comment) {
                    const analysis = await analyzeWithAI(comment);
                    displayComment(comment, analysis);
                    updateStats(analysis);
                }
            }

            // Final UI update
            renderStats();

        } catch (error) {
            console.error('Error:', error);
            commentsList.innerHTML = `
                <div class="empty-state">
                    ${error.message || 'An error occurred'}
                </div>
            `;
        } finally {
            loading.style.display = 'none';
        }
    });

    // AI Analysis function
    async function analyzeWithAI(comment) {
        try {
            const response = await fetch('https://api.openai.com/v1/chat/completions', {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json',
                    'Authorization': `Bearer ${API_KEY}`
                },
                body: JSON.stringify({
                    model: 'gpt-4',
                    messages: [
                        {
                            role: 'system',
                            content: `Analyze eLearning feedback comments.
                                    Categories: [Content, Bug, Accessibility, Enhancement]
                                    Roles: [Storyboard Creator, Developer, Designer, QA]
                                    Respond with JSON only: {"category": "", "role": ""}`
                        },
                        {
                            role: 'user',
                            content: comment
                        }
                    ],
                    temperature: 0.3
                })
            });

            if (!response.ok) {
                throw new Error(`API Error: ${response.status}`);
            }

            const data = await response.json();
            return JSON.parse(data.choices[0].message.content);

        } catch (error) {
            console.error('AI Analysis error:', error);
            return {
                category: 'Unknown',
                role: 'Unassigned'
            };
        }
    }

    // Display comment in UI
    function displayComment(comment, analysis) {
        const div = document.createElement('div');
        div.className = 'comment-item';
        div.innerHTML = `
            <div class="comment-text">${comment}</div>
            <div class="comment-meta">
                <span class="tag category-tag">${analysis.category}</span>
                <span class="tag role-tag">${analysis.role}</span>
            </div>
        `;
        commentsList.appendChild(div);
    }

    // Stats functions
    function resetStats() {
        stats = {
            total: 0,
            assigned: 0,
            categories: new Set()
        };
        renderStats();
    }

    function updateStats(analysis) {
        stats.total++;
        if (analysis.role !== 'Unassigned') {
            stats.assigned++;
        }
        if (analysis.category !== 'Unknown') {
            stats.categories.add(analysis.category);
        }
    }

    function renderStats() {
        totalNumber.textContent = stats.total;
        assignedNumber.textContent = stats.assigned;
        categoriesNumber.textContent = stats.categories.size;
    }
    
    // Export to Excel function
    exportBtn.addEventListener('click', function() {
        if (analyzedComments.length === 0) return;
        
        // Create CSV content
        let csvContent = "data:text/csv;charset=utf-8,";
        
        // Add header row
        csvContent += "Comment,Category,Assigned Role\n";
        
        // Add data rows
        analyzedComments.forEach(item => {
            // Escape quotes in comment text and wrap in quotes to handle commas
            const escapedComment = `"${item.comment.replace(/"/g, '""')}"`;
            csvContent += `${escapedComment},${item.category},${item.role}\n`;
        });
        
        // Create download link
        const encodedUri = encodeURI(csvContent);
        const link = document.createElement("a");
        link.setAttribute("href", encodedUri);
        link.setAttribute("download", "comment_analysis.csv");
        document.body.appendChild(link);
        
        // Trigger download
        link.click();
        document.body.removeChild(link);
    });
});
